package repos

import (
	"context"
	"log/slog"
	"os"

	"github.com/jackc/pgx/v5/pgxpool"
)

type AllRepos interface {
	RoomsRepo
	ActionsRepo
	PlayersRepo
}

type RepoProvider struct {
	DB *pgxpool.Pool
}

func NewRepoProvider(pathToDB string) *RepoProvider {
	dbpool, err := pgxpool.New(context.Background(), pathToDB)
	if err != nil {
		slog.Error("Unable to connect to database", "error", err)
		os.Exit(1)
	}
	slog.Info("Successfully connected to database")
	return &RepoProvider{
		DB: dbpool,
	}
}
